@@ -57,7 +57,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::Plugin::Manifest::Write
 # ABSTRACT: Have annotated distribution manifest
-our $VERSION = 'v0.9.6'; # VERSION
+our $VERSION = 'v0.9.6_01'; # TRIAL VERSION
 
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -69,8 +69,10 @@ with 'Dist::Zilla::Role::FileFinderUser' => {
 };
 
 use Dist::Zilla::File::FromCode;
+use ExtUtils::Manifest qw{};
 use List::Util;
 use Module::Util qw{ is_valid_module_name };
+use Path::Tiny qw{};
 use Readonly;
 use Set::Object qw{};
 use String::RewritePrefix;
@@ -198,6 +200,20 @@ around BUILDARGS => sub {
 
 # --------------------------------------------------------------------------------------------------
 
+has _heading => (
+    isa     => 'Str',
+    is      => 'ro',
+    lazy    => 1,
+    builder => '_build_heading',
+);
+
+sub _build_heading {
+    my ( $self ) = @_;
+    return sprintf( "# This file was generated with %s %s.", blessed( $self ), $self->VERSION );
+};
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =attr manifest
 #pod
 #pod Name of manifest file to write.
@@ -207,11 +223,100 @@ around BUILDARGS => sub {
 #pod =cut
 
 has manifest => (
-    isa     => 'Str',
-    is      => 'ro',
-    default => 'MANIFEST',
+    isa         => 'Str',
+    is          => 'ro',
+    default     => 'MANIFEST',
 );
 
+has _manifest_file => (
+    isa         => 'Dist::Zilla::Role::File',
+    is          => 'ro',
+    lazy        => 1,
+    init_arg    => undef,
+    builder     => '_build_manifest_file',
+);
+
+sub _build_manifest_file {
+    my ( $self ) = @_;
+    my $zilla = $self->zilla;
+    return Dist::Zilla::File::FromCode->new( {
+        name                => $self->manifest,
+        code_return_type    => 'bytes',
+        code                => sub {
+            my @list;
+            my $files = Set::Object->new( @{ $zilla->files } );
+            $files->remove( @{ $self->found_files } );
+            #   Process all files in alphbetical order.
+            for my $file ( sort( { $a->name cmp $b->name } @{ $files } ) ) {
+                push( @list, {
+                    name    => $self->_file_name( $file ),
+                    comment => $self->_file_comment( $file )
+                } );
+            };
+            $self->abort_if_error();    # `_file_comment` methods may generate errors.
+            #   Find width of filename column.
+            my $width = List::Util::max( map( { length( $_->{ name } ) } @list ) );
+            #   Output formats.
+            my $body = "%*s # %s";
+            return
+                join(
+                    "\n",
+                    $self->_heading,
+                    map( { sprintf( $body, - $width, $_->{ name }, $_->{ comment } ) } @list ),
+                ) . "\n";
+        },
+    } );
+};
+
+# --------------------------------------------------------------------------------------------------
+
+#pod =attr manifest_skip
+#pod
+#pod Name of manifest.skip file to write.
+#pod
+#pod C<Str>, read-only. Default value is C<'MANIFEST.SKIP'>.
+#pod
+#pod =cut
+
+has manifest_skip => (
+    isa         => 'Str',
+    is          => 'ro',
+    default     => 'MANIFEST.SKIP',
+);
+
+
+has _manifest_skip_file => (
+    isa         => 'Maybe[Dist::Zilla::Role::File]',
+    is          => 'ro',
+    lazy        => 1,
+    init_arg    => undef,
+    builder     => '_build_manifest_skip',
+);
+
+sub _build_manifest_skip {
+    my ( $self ) = @_;
+    return if $self->manifest_skip eq '';
+    return Dist::Zilla::File::FromCode->new( {
+        name                => $self->manifest_skip,
+        code_return_type    => 'bytes',
+        code                => sub {
+            my $default = Path::Tiny::path( $ExtUtils::Manifest::DEFAULT_MSKIP );
+            return join( "\n",
+                $self->_heading,
+                '',
+                map( { "^" . quotemeta( $_->name ) . "\$" } @{ $self->found_files } ),
+                '',
+                #   `ExtUtils::Manifest` recognizes `#!include_default` directive. Unfortunately,
+                #   `Module::Manifest` does not. So I have to copy default `MANIFEST.SKIP`.
+                "# The rest is a copy of $default file:",
+                '',
+                $default->slurp_utf8(),
+                '# end of file #'
+            ) . "\n";
+        },
+    } );
+};
+
 # --------------------------------------------------------------------------------------------------
 
 #pod =attr source_providers
@@ -432,6 +537,15 @@ sub _build_dw {
 
 # --------------------------------------------------------------------------------------------------
 
+around found_files => sub {
+    my ( $orig, $self ) = @_;
+    my $found = $self->$orig();
+    push( @$found, $self->_manifest_skip_file ) if defined $self->_manifest_skip_file;
+    return $found;
+};
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =method before_build
 #pod
 #pod This method is called by C<Dist::Zilla> automatically before build. The method checks validity of
@@ -490,36 +604,8 @@ sub before_archive {
 
 sub gather_files {
     my ( $self, $arg ) = @_;
-    my $zilla = $self->zilla;
-    my $file = Dist::Zilla::File::FromCode->new( {
-        name                => $self->manifest,
-        code_return_type    => 'bytes',
-        code                => sub {
-            my @list;
-            my $files = Set::Object->new( @{ $zilla->files } );
-            $files->remove( @{ $self->found_files } );
-            #   Process all files in alphbetical order.
-            for my $file ( sort( { $a->name cmp $b->name } @{ $files } ) ) {
-                push( @list, {
-                    name    => $self->_file_name( $file ),
-                    comment => $self->_file_comment( $file )
-                } );
-            };
-            $self->abort_if_error();    # `_file_comment` methods may generate errors.
-            #   Find width of filename column.
-            my $width = List::Util::max( map( { length( $_->{ name } ) } @list ) );
-            #   Output formats.
-            my $head = "# This file was generated with %s %s\n";
-            my $body = "%*s # %s\n";
-            return
-                join(
-                    '',
-                    sprintf( $head, blessed( $self ), $self->VERSION ),
-                    map( { sprintf( $body, - $width, $_->{ name }, $_->{ comment } ) } @list ),
-                );
-        },
-    } );
-    $self->add_file( $file );
+    $self->add_file( $self->_manifest_file );
+    $self->add_file( $self->_manifest_skip_file ) if defined $self->_manifest_skip_file;
     return;
 };
 
@@ -845,9 +931,9 @@ __PACKAGE__->meta->make_immutable;
 #pod
 #pod A module shown in Synopsis is a real example. Its result looks like:
 #pod
-#pod     # This file was generated with ManifestWithFileSize 0.007
+#pod     # This file was generated with ManifestWithFileSize 0.007.
 #pod     MANIFEST     #  metainfo file built by =ManifestWithFileSize
-#pod     dist.ini     #     Dummy file added by GatherDir (207 bytes)
+#pod     dist.ini     #     Dummy file added by GatherDir (239 bytes)
 #pod     lib/Dummy.pm #     Dummy file added by GatherDir (22 bytes)
 #pod
 #pod
@@ -901,7 +987,8 @@ Dist::Zilla::Plugin::Manifest::Write - Have annotated distribution manifest
 
 =head1 VERSION
 
-Version v0.9.6, released on 2016-12-03 22:41 UTC.
+Version v0.9.6_01, released on 2016-12-09 21:24 UTC.
+This is a B<trial release>.
 
 =head1 WHAT?
 
@@ -967,6 +1054,12 @@ Name of manifest file to write.
 
 C<Str>, read-only. Default value is C<'MANIFEST'>.
 
+=head2 manifest_skip
+
+Name of manifest.skip file to write.
+
+C<Str>, read-only. Default value is C<'MANIFEST.SKIP'>.
+
 =head2 source_providers
 
 List of plugin names. Enlisted plugins are considered as source file providers. A file added to
@@ -1174,9 +1267,9 @@ accepts also reference to plugin object.
 
 A module shown in Synopsis is a real example. Its result looks like:
 
-    # This file was generated with ManifestWithFileSize 0.007
+    # This file was generated with ManifestWithFileSize 0.007.
     MANIFEST     #  metainfo file built by =ManifestWithFileSize
-    dist.ini     #     Dummy file added by GatherDir (207 bytes)
+    dist.ini     #     Dummy file added by GatherDir (239 bytes)
     lib/Dummy.pm #     Dummy file added by GatherDir (22 bytes)
 
 =head1 SEE ALSO
